﻿using Esri.ArcGISRuntime.Data;
using Esri.ArcGISRuntime.Geometry;
using Esri.ArcGISRuntime.LocalServices;
using Esri.ArcGISRuntime.Mapping;
using Esri.ArcGISRuntime.Tasks.Offline;
using Esri.ArcGISRuntime.UI.Controls;
using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Threading;

namespace LoadShp
{
    public class MapLoader
    {
        private static MapLoader instance;
        public static MapLoader Instance
        {
            get
            {
                if (instance == null)
                {
                    instance = new MapLoader();
                }
                return instance;
            }
        }

        private MapLoader() { }

        //private GeodatabaseSyncTask gdbSyncTask;

        private Map webmap;
        private MapView mapView;
        private Dispatcher d;
        //private Uri _featureServiceUri = new Uri("https://services3.arcgis.com/OAHlCDszQf7JvlFi/arcgis/rest/services/APLICATIE_TURCENI_FINAL/FeatureServer");
        //private Uri _featureServiceUri2 = new Uri("https://services3.arcgis.com/OAHlCDszQf7JvlFi/arcgis/rest/services/Agricultura_App2/FeatureServer");
        private LocalMapService _localMapService;

        public void setUpMapVariables(Dispatcher d, MapView mapView)
        {
            this.d = d;
            this.mapView = mapView;
        }

        public async void LoadWebMap()
        {

            webmap = new Map(SpatialReference.Create(31700));
            await webmap.LoadAsync();
            webmap.InitialViewpoint = new Viewpoint(new MapPoint(2601653.39221207, 5569387.41455324, SpatialReferences.WebMercator), 360000); //got this from event.Location
            mapView.Map = webmap;

            LocalServer.Instance.StatusChanged += ServerStatusChanged;
            await LocalServer.Instance.StartAsync();
        }

        private async void ServerStatusChanged(object sender, StatusChangedEventArgs e)
        {
            if (e.Status == LocalServerStatus.Started)
            {
                _localMapService = new LocalMapService(Environment.CurrentDirectory + @"\Maps\Turceni_map.mpk");
                //_localMapService.StatusChanged += _localMapService_StatusChanged;
                await _localMapService.StartAsync();
            }
            
        }

        private async void _localMapService_StatusChanged(object sender, StatusChangedEventArgs e)
        {
            if (e.Status == LocalServerStatus.Started)
            {
                ArcGISMapImageLayer imageryLayer = new ArcGISMapImageLayer(_localMapService.Url);
                await imageryLayer.LoadAsync();
                mapView.Map.OperationalLayers.Clear();

                // Add the image layer to the map
                mapView.Map.OperationalLayers.Add(imageryLayer);
            }
        }
    }
}
